]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - setup.sh
replace Xdefaults with Xresources
[config/dotfiles.git] / setup.sh
index 9e330d1231dfea8c5c39ff2f1b6824c58af08925..368fa0b7b07b4a1e0ea1559fa7704f966a762af1 100755 (executable)
--- a/setup.sh
+++ b/setup.sh
@@ -37,7 +37,7 @@ if installed X; then
     # Prevent code duplication. Term* rules are for all terminals; XTerm rules
     # are for XTerm and UXTerm. At the moment XTerm, UXTerm and Rxvt are
     # supported.
-    generate Xdefaults .in perl -ne \
+    generate Xresources .in perl -ne \
         'if (/^Term/) {
              s/^Term//;
              print "XTerm", $_;
@@ -50,14 +50,14 @@ if installed X; then
          } else {
              print $_;
          }'
-    # Xdefaults uses ! as comment instead of #.
-    sed_i 's/^#/!/' Xdefaults
+    # Xresources uses ! as comment instead of #.
+    sed_i 's/^#/!/' Xresources
     # Use urxvt's pseudo-transparency if compton is not available. Better than
     # nothing.
     if ! installed compton; then
-        echo 'Xdefaults: no compton found, enabling pseudo-transparency'
-        sed_i 's/^Rxvt\*background/!&/' Xdefaults
-        sed_i 's/^!NO_COMPTON //' Xdefaults
+        echo 'Xresources: no compton found, enabling pseudo-transparency'
+        sed_i 's/^Rxvt\*background/!&/' Xresources
+        sed_i 's/^!NO_COMPTON //' Xresources
     fi
 
     if test ! "x`os`" = xdarwin; then
@@ -72,7 +72,7 @@ if installed X; then
         link xinitrc.local ~/.xinitrc.local
     fi
     link xmodmaprc ~/.xmodmaprc
-    link Xdefaults ~/.Xdefaults
+    link Xresources ~/.Xresources
     link XCompose ~/.XCompose
 fi